.. _routines.datetime:

Datetime Support Functions
**************************

.. currentmodule:: numpy

.. autosummary::
   :toctree: generated/

   datetime_as_string
   datetime_data


Business Day Functions
======================

.. currentmodule:: numpy

.. autosummary::
   :toctree: generated/

   busdaycalendar
   is_busday
   busday_offset
   busday_count
